إدارة التوعية الإسلامية - بنات>>التوعية الإسلامية"بنات" بتعليم حائل تقيم دورات تنشيطية لمسئولات المصلى
Description: أقامت الشؤون التعليمية ممثلة بإدارة التوعية الإسلامية بتعليم حائل اليوم الخميس الموافق 12/11/1436 هـ عدد من الحلقات التنشيطية لمسؤولات المصلى في عدد من المدارس التابعة لمكاتب التعليم بمنطقة حائل والتي شملت المتوسطة الخامسة التابعة لمكتب شمال والمتوسط ...

تسجيل الدخول
أسم الدخول
كلمة المرور
رمز التحقق
نسيت كلمة المرور

- قيمي تيوب

استفتاء الموقع
ما رأيكم في الموقع الجديد ؟
الموقع السابق افضل
الموقع الحالي افضل
يحتاج الى التطوير
ما رأيكم في الموقع الجديد ؟
التصويت
النتائج
فيديو

#

- الرئيسية >>
- اخبار الادارة

التوعية الإسلامية"بنات" بتعليم حائل تقيم دورات تنشيطية لمسئولات المصلى

الأربعاء 22/01/1437 الساعة 22:07 هـ (مكة المكرمة)
أقامت الشؤون التعليمية ممثلة بإدارة التوعية الإسلامية بتعليم حائل اليوم الخميس الموافق 12/11/1436 هـ عدد من الحلقات التنشيطية لمسؤولات المصلى في عدد من المدارس التابعة لمكاتب التعليم بمنطقة حائل والتي شملت المتوسطة الخامسة التابعة لمكتب شمال والمتوسطة التاسعة عشر التابعة لمكتب شرق والثانوية الثانية التابعة لمكتب جنوب
والتي تهدف الى شرح برامج التوعية الإسلامية لهذا العام مع عرض لبرامج الاستقامة و توزيع أقراص لمسابقة الأمير نايف بن عبدالعزيز آل سعود لحفظ الحديث النبوي وتوزيع برنامج ترحيبي بالمصليات وكما تم توزيع أستمارة مسح ميداني للمصليات واستمارة واستمارة قاعدة البيانات .

جميع الحقول مطلوبة

إسمك إسم المرسل إليه بريدك الإلكتروني بريد المستقبل الموضوع

جاري التحميل